// --------------------------------------
// Edit header file (networkParameters.h)
//   according to your network parameters
// --------------------------------------
#include "networkParameters.h"
// Variables
char wifiStatus;
char response;

char socketHandle = 0;
char bindResult;
char dat[25] = "mikroE\r\n";
unsigned int cntBytes;

// Helper function
void LCD_ClrLine(char line) {
    Lcd_Out(line, 1, "                ");
}

// Initialization of Wifi Module
void Init_WiFi() {
    unsigned int  response;
    Lcd_Cmd(_LCD_CLEAR);
    Lcd_Out(1, 1, "Configuration");
    Lcd_Out(2, 1, " in progress");
    Delay_ms(500);
    Net_Wireless_MCW1001_TimeToWait = 2;
    response = 1;
    response = Net_Wireless_MCW1001_SetMode(_NET_WIRELESS_MCW1001_CP_1,_NET_WIRELESS_MCW1001_MODE_INFRASTRUCTURE);
    response += Net_Wireless_MCW1001_SetChannelList(sizeof(channels), channels);
    response += Net_Wireless_MCW1001_SetSecurity_WPA(_NET_WIRELESS_MCW1001_CP_1, _NET_WIRELESS_MCW1001_WPA_PSK2, wpaPassword);
    response += Net_Wireless_MCW1001_SetSSID(_NET_WIRELESS_MCW1001_CP_1, strSSID);
    response += Net_Wireless_MCW1001_SetNetworkMask(ipMask);
    response += Net_Wireless_MCW1001_SetGatewayIP(gwIpAddr);
    response += Net_Wireless_MCW1001_SetMAC(myMacAddr);
    response += Net_Wireless_MCW1001_SetIP(myIpAddr);
    response += Net_Wireless_MCW1001_SetArpTime(1);
    response += Net_Wireless_MCW1001_SetRetryCount(5, 0);
    if (response > 0) {
        LCD_ClrLine(2);
        Lcd_Out(2, 1, "     ERROR!     ");
        while(1)
            ;         // Check the value of each response to see what is causing the error
    }
}
// Connecting to Access Point
void ConnectToAp() {
    Lcd_Cmd(_LCD_CLEAR);
    Lcd_Out(1, 1, "Connecting to AP");
    Lcd_Out(2,1,  "it takes a while");      // Write text in second row
    // Connect to AP
    Net_Wireless_MCW1001_TimeToWait = 40;
    response = Net_Wireless_MCW1001_Connect(_NET_WIRELESS_MCW1001_CP_1, &wifiStatus);
    Net_Wireless_MCW1001_TimeToWait = 5;
    if((response == 0) && (wifiStatus == 1)) {
        return;
    } else {
        LCD_ClrLine(2);
        Lcd_Out(2, 1, "     FAILED     ");
        while(1)                            // Probably need to edit networkPrameters.h file
            ;
    }
}

// Handling the UDP data sent from remoteIP
void UDP_Handler() {
    int i;
    unsigned short cnt;
    response=Net_Wireless_MCW1001_SocketCreate(&socketHandle,_NET_WIRELESS_MCW1001_SOCKET_TYPE_UDP);
    if(response == _NET_WIRELESS_MCW1001_NO_ERROR) {
        LCD_ClrLine(2);
        Lcd_Out(2, 1, "Socket is OK");
        Delay_ms(600);
    }
    Net_Wireless_MCW1001_SocketBind(socketHandle, &localPort, &bindResult);
    if(bindResult < 254) {
        LCD_ClrLine(2);
        Lcd_Out(2, 1, "Bind is OK");
        Delay_ms(600);
    }
    Net_Wireless_MCW1001_TimeToWait = 5;
    response = Net_Wireless_MCW1001_UDP_SendBytes(socketHandle, remotePort, remoteIP, dat, strlen(dat), &cntBytes);
    if (cntBytes == 8) {                 // dat = "mikroE\r\n"; strlen("mikroE\r\n") = 8
        LCD_ClrLine(2);
        Lcd_Out(2, 1, "UPD Sent!");
    }
    Net_Wireless_MCW1001_TimeToWait = 2;
    while(1) {
        response=Net_Wireless_MCW1001_UDP_ReadBytes(&socketHandle, sizeof(dat) ,&remotePort, remoteIP, &dat, &cntBytes);
        if(response == 0 ) {
            Lcd_Out(1, 1, "Received:       ");
            cnt = 0;
            if (cntBytes < 17) {         // All received data can be shown on single LCD line
                Lcd_Chr(1, 16, ' ');
                dat[cntBytes] = 0;
            } else {                     // Only 16 bytes of data will be displayed and echoed back
                Lcd_Chr(1, 16, '!');     // Exlamation indicates ON LCD that recived data is too long for LCD line
                dat[16] = 0;             // Sting will be limited to 16 characters - adding zero teminaging character
            }
            LCD_ClrLine(2);              // Prepare line 2 for data display
            Lcd_Out(2, 1, dat);          // Show recived data
            // Echo back the deta which is show on display
            response = Net_Wireless_MCW1001_UDP_SendString(socketHandle, remotePort, remoteIP, dat, &cntBytes);
        }
        if (cnt++ > 2) {
            cnt = 0;
            Lcd_Out(1, 1, "I'm waiting...  ");
            LCD_ClrLine(2);
        }
    }
}