/*
 * Project name:
      WiFi Plus click - UDP Example
 * Copyright:
      (c) mikroElektronika, 2014.
 * Revision History:
      20140424:
      - Initial release (DO);
 * Description:
      This is demonstartion project how to send and receive UDP packages with WiFi Plus click.
      Before compiling this project, it's mandatory to modify the networkParameters.h file.
      Values used in networkParameters.h are only for description.

      After successfuly connecting to Access Point,
        "mikroE" will be sent to IP address (via UDP) which is defined in remoteIP array.
      Data sent from same IP address (remoteIP) is polled, 
        when received - data is trimed if needed to be displayed on LCD 
        and sent back to remoteIP via UDP (data show in LCD).
 * Test configuration:
     MCU:             PIC18F4550
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39632e.pdf
     Dev. Board:      EasyPIC v7
                      http://www.mikroe.com/easypic/
     Oscillator:      HS-PLL, 8.000 MHz Crystal, 48.000 MHz MCU Clock
     Ext. Modules:    WiFi Plus click - ac:WiFi_Plus_click
                      http://www.mikroe.com/click/wifi-plus/
                      Character LCD 2x16 - ac:LCD
                      http://www.mikroe.com/store/components/displays/
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/mikroc/pic/
 * NOTES:
      - Place WiFi Plus click board in the mikroBUS socket 2.
      - Connect the LCD.
      - Turn ON LCD backlight SW4.6
      - Turn ON portD LEDs SW3.4 to check the 1sec puls.
*/

// Reset Pin Description of The Wifi Plus Click
sbit Net_Wireless_MCW1001_Chip_RST at LATE2_bit;
sbit Net_Wireless_MCW1001_Chip_RST_Direction at TRISE2_bit;

// Lcd module connections
sbit LCD_RS at LATB4_bit;
sbit LCD_EN at LATB5_bit;
sbit LCD_D4 at LATB0_bit;
sbit LCD_D5 at LATB1_bit;
sbit LCD_D6 at LATB2_bit;
sbit LCD_D7 at LATB3_bit;
sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;

// Pulst LED definition
sbit PulsLED at LATD.B0;
sbit PulsLED_Direction at TRISD.B0;

// Timer0 Interrupt Routine  - 40ms period
unsigned int wifiTmr = 0;
void interrupt() {
    if (TMR0IF_bit) {
        if( ++wifiTmr >= 25 ) {
            Net_Wireless_MCW1001_Time++;
            wifiTmr = 0;
            PulsLED = ~PulsLED;        // 1sec. indicator.
        }
        TMR0IF_bit = 0;
        TMR0H      = 0x15;
        TMR0L      = 0xA0;
    }
}
// Initialization of MCU
void Init_MCU() {
    ADCON1  = 0x0F;
    CMCON   = 0x07;
    PulsLED_Direction = 0;
    // Configure timer module - enable interrupt
    T0CON	  = 0x82;
    TMR0H	  = 0x15;
    TMR0L	  = 0xA0;
    GIE_bit = 1;

    Lcd_Init();                        // Initialize Lcd
    Lcd_Cmd(_LCD_CLEAR);               // Clear display
    Lcd_Cmd(_LCD_CURSOR_OFF);          // Cursor off
    Lcd_Out(1, 1, "WiFi Plus click");  // Write text in first row
    Lcd_Out(2, 1, "UDP send/recive");  // Write text in first row
    Delay_ms(2000);
    Net_Wireless_MCW1001_HwReset();
    UART1_Init(115200);
    Delay_ms(1500);
}
// WiFi_functions.c
void Init_WiFi();
void ConnectToAp();
void UDP_Handler();
// ---
void main() {
    Init_MCU();      // Configure MCU registers and modules
    TMR0IE_bit = 1;  // Start counting seconds
    Init_WiFi();     // Cinfigure module with parameters defined in networkParameters.h
    ConnectToAp();   // Try to connect to AP defined (SSID and password) in networkParameters.h
    UDP_Handler();   // Send/Recive UDP data
}